# Generated by roxygen2: do not edit by hand

S3method(head,GENEAbin)
S3method(levels,GENEA)
export(CirDisp)
export(CirKurt)
export(CirSD)
export(CirSkew)
export(CirVar)
export(GENEAcount)
export(GENEAratio)
export(GENEAskew)
export(MeanDir)
export(abssumdiff)
export(changeTimes)
export(classifyGENEA)
export(createGENEAmodel)
export(dataImport)
export(degrees)
export(features)
export(getGENEAsegments)
export(impact)
export(meandiff)
export(radians)
export(removeShortSegments)
export(sddiff)
export(segmentation)
export(sod)
export(stepCounter)
export(sumdiff)
export(updown)
import(GENEAread)
import(MASS)
import(changepoint)
import(rpart)
import(utils)
importFrom(grDevices,dev.off)
importFrom(grDevices,hcl)
importFrom(grDevices,png)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(methods,is)
importFrom(signal,cheby1)
importFrom(stats,as.formula)
importFrom(stats,filter)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
